==> colcon_package_information-0.1.0-py3-none-any.whl: colcon_package_information/verb/info.py <==
# Copyright 2016-2018 Dirk Thomas
# Licensed under the Apache License, Version 2.0

from colcon_core.package_decorator import add_recursive_dependencies
from colcon_core.package_decorator import get_decorators
from colcon_core.package_selection import add_arguments \
    as add_packages_arguments
from colcon_core.package_selection import get_package_descriptors
from colcon_core.package_selection import select_package_decorators
from colcon_core.plugin_system import satisfies_version
from colcon_core.verb import VerbExtensionPoint


class InfoVerb(VerbExtensionPoint):
    """Package information."""

    def __init__(self):  # noqa: D107
        super().__init__()
        satisfies_version(VerbExtensionPoint.EXTENSION_POINT_VERSION, '^1.0')

    def add_arguments(self, *, parser):  # noqa: D102
        parser.add_argument(
            'path', nargs='?',
            help='Specific path to check for package (ignore other discovery '
                 'arguments)')
        add_packages_arguments(parser)

    def main(self, *, context):  # noqa: D102
        # modify args to match path discovery extension
        if context.args.path is not None:
            context.args.paths = [context.args.path]

        descriptors = get_package_descriptors(
            context.args, additional_argument_names=['*'])
        decorators = get_decorators(descriptors)
        if context.args.path is None:
            add_recursive_dependencies(
                decorators, recursive_categories=('run', ))
            select_package_decorators(context.args, decorators)

        if not descriptors:
            return 'No package found'

        for decorator in decorators:
            if not decorator.selected:
                continue
            pkg = decorator.descriptor
            print('path:', pkg.path)
            print('  type:', pkg.type)
            print('  name:', pkg.name)
            if pkg.dependencies:
                print('  dependencies:')
                for category in sorted(pkg.dependencies.keys()):
                    print(
                        '    {category}:'.format_map(locals()),
                        ' '.join(sorted(pkg.dependencies[category])))
            if pkg.hooks:
                print('  hooks:', ' '.join(pkg.hooks))
            if pkg.metadata:
                print('  metadata:')
                for key in sorted(pkg.metadata.keys()):
                    value = pkg.metadata[key]
                    print(
                        '    {key}: {value}'
                        .format_map(locals()))

==> colcon_package_information-0.2.1-py3-none-any.whl: colcon_package_information/verb/info.py <==
# Copyright 2016-2018 Dirk Thomas
# Licensed under the Apache License, Version 2.0

import sys

from colcon_core.package_decorator import add_recursive_dependencies
from colcon_core.package_decorator import get_decorators
from colcon_core.package_selection import add_arguments \
    as add_packages_arguments
from colcon_core.package_selection import get_package_descriptors
from colcon_core.package_selection import select_package_decorators
from colcon_core.plugin_system import satisfies_version
from colcon_core.verb import VerbExtensionPoint


class InfoVerb(VerbExtensionPoint):
    """Package information."""

    def __init__(self):  # noqa: D107
        super().__init__()
        satisfies_version(VerbExtensionPoint.EXTENSION_POINT_VERSION, '^1.0')

    def add_arguments(self, *, parser):  # noqa: D102
        parser.add_argument(
            'package_names', nargs='*', metavar='PKG_NAME',
            help='Only show the information of a subset of packages')
        add_packages_arguments(parser)

    def main(self, *, context):  # noqa: D102
        descriptors = get_package_descriptors(
            context.args, additional_argument_names=['*'])
        decorators = get_decorators(descriptors)
        add_recursive_dependencies(
            decorators, recursive_categories=('run', ))
        select_package_decorators(context.args, decorators)

        if context.args.package_names:
            all_package_names = {d.descriptor.name for d in decorators}
            # warn about passed package names which are unknown
            for pkg_name in context.args.package_names:
                if pkg_name not in all_package_names:
                    print(
                        "Package '{pkg_name}' not found".format_map(locals()),
                        file=sys.stderr)
            # filter decorators using passed package names
            decorators = [
                d for d in decorators
                if d.descriptor.name in context.args.package_names]
            if not decorators:
                return 1
        if not decorators:
            return 'No packages found'

        for decorator in sorted(decorators, key=lambda d: d.descriptor.name):
            if not decorator.selected:
                continue
            pkg = decorator.descriptor
            print('path:', pkg.path)
            print('  type:', pkg.type)
            print('  name:', pkg.name)
            if pkg.dependencies:
                print('  dependencies:')
                for category in sorted(pkg.dependencies.keys()):
                    print(
                        '    {category}:'.format_map(locals()),
                        ' '.join(sorted(pkg.dependencies[category])))
            if pkg.hooks:
                print('  hooks:', ' '.join(pkg.hooks))
            if pkg.metadata:
                print('  metadata:')
                for key in sorted(pkg.metadata.keys()):
                    value = pkg.metadata[key]
                    print(
                        '    {key}: {value}'
                        .format_map(locals()))
